<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Artist extends Model
{
    use HasFactory;

    use SoftDeletes;

    protected $table = 'artists';

    protected $dates = ['created_at', 'updated_at', 'deleted_at'];

    protected $casts = [
        'created_at' => 'datetime',
        'updated_at' => 'datetime',
        'deleted_at' => 'datetime',
    ];

    protected $fillable = [
        'user_id',
        'name',
        'slug',
        'avatar',
        'header',
        'location',
        'website',
        'bio',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public function user()
    {
        return $this->belongsTo(User::class);
    }

    public function artworks()
    {
        return $this->hasMany(Artwork::class);
    }

    public function overlays()
    {
        return $this->hasMany(Overlay::class);
    }

    public function episodes()
    {
        return $this->hasManyThrough(Episode::class, Artwork::class);
    }

    public function wallets()
    {
        return $this->hasMany(Wallet::class);
    }

}
